@@ -6,6 +6,7 @@ import six
 
 class RuleError(RuntimeError):
     def __init__(self, rule):
+        RuntimeError.__init__(self)
         self.Rule = rule
 
     def __str__(self):
@@ -14,6 +15,7 @@ class RuleError(RuntimeError):
 
 class InvalidTokenError(RuntimeError):
     def __init__(self, s, str_index):
+        RuntimeError.__init__(self)
         self.string = s
         self.index = str_index
 
@@ -24,6 +26,7 @@ class InvalidTokenError(RuntimeError):
 
 class ParseError(RuntimeError):
     def __init__(self, msg, s, token):
+        RuntimeError.__init__(self)
         self.message = msg
         self.string = s
         self.Token = token
@@ -46,56 +49,58 @@ class RE(object):
         return "RE(%s)" % self.Content
 
 
+def _matches_rule(rule, s, start, rule_dict, debug=False):
+    if debug:
+        print("Trying", rule, "on", s[start:])
+
+    if isinstance(rule, tuple):
+        if rule[0] == "|":
+            for subrule in rule[1:]:
+                length, match_obj = _matches_rule(
+                        subrule, s, start, rule_dict, debug)
+                if not length:
+                    continue
+                return length, match_obj
+        else:
+            my_match_length = 0
+            for subrule in rule:
+                length, _ = _matches_rule(
+                        subrule, s, start, rule_dict, debug)
+                if not length:
+                    break
+                my_match_length += length
+                start += length
+            else:
+                return my_match_length, None
+        return 0, None
+
+    elif isinstance(rule, six.string_types):
+        return _matches_rule(rule_dict[rule], s, start, rule_dict, debug)
+
+    elif isinstance(rule, RE):
+        match_obj = rule.RE.match(s, start)
+        if match_obj:
+            return match_obj.end()-start, match_obj
+        return 0, None
+
+    raise RuleError(rule)
+
+
 def lex(lex_table, s, debug=False, match_objects=False):
     rule_dict = dict(lex_table)
-
-    def matches_rule(rule, s, start):
-        if debug:
-            print("Trying", rule, "on", s[start:])
-        if isinstance(rule, tuple):
-            if rule[0] == "|":
-                for subrule in rule[1:]:
-                    length, match_obj = matches_rule(
-                            subrule, s, start)
-                    if length:
-                        return length, match_obj
-                return 0, None
-            else:
-                my_match_length = 0
-                for subrule in rule:
-                    length, _ = matches_rule(subrule, s, start)
-                    if length:
-                        my_match_length += length
-                        start += length
-                    else:
-                        return 0, None
-                return my_match_length, None
-        elif isinstance(rule, six.string_types):
-            return matches_rule(rule_dict[rule], s, start)
-        elif isinstance(rule, RE):
-            match_obj = rule.RE.match(s, start)
-            if match_obj:
-                return match_obj.end()-start, match_obj
-            else:
-                return 0, None
-        else:
-            raise RuleError(rule)
-
     result = []
     i = 0
     while i < len(s):
-        rule_matched = False
         for name, rule in lex_table:
-            length, match_obj = matches_rule(rule, s, i)
+            length, match_obj = _matches_rule(rule, s, i, rule_dict, debug)
             if length:
                 if match_objects:
                     result.append((name, s[i:i+length], i, match_obj))
                 else:
                     result.append((name, s[i:i+length], i))
                 i += length
-                rule_matched = True
                 break
-        if not rule_matched:
+        else:
             raise InvalidTokenError(s, i)
     return result
 
@@ -136,7 +141,9 @@ class LexIterator(object):
         return self.index + i >= len(self.lexed)
 
     def is_next(self, tag, i=0):
-        return self.next_tag(i) is tag
+        return (
+                self.index + i < len(self.lexed)
+                and self.next_tag(i) is tag)
 
     def raise_parse_error(self, msg):
         if self.is_at_end():
